import net.idrnd.facesdk.*;

public class Example {
    private static final String IDLIVEFACE_HOME = "/opt/idliveface";

    private static Pipeline createPipeline() {
        System.out.println("Initializing...");
        try (InitConfig config = new InitConfig(IDLIVEFACE_HOME + "/data/pipelines/astraea.json")) {
            return new Pipeline("ConfigurablePipeline", config);
        }
    }

    private static void processLivenessResult(PipelineResult result) {
        System.out.println("Result: " + result);

        if (result.getQualityResult().getScore() < 0.5) {
            System.out.println("Image has a bad quality");
        } else if (result.getLivenessResult().getProbability() >= 0.5) {
            System.out.println("Image is genuine");
        } else {
            System.out.println("Image is spoofed");
        }
    }

    public static void main(String[] args) {
        try (Pipeline pipeline = createPipeline()) {
            System.out.println("\nChecking liveness for real_face.jpg");

            try (Image image = new Image(IDLIVEFACE_HOME + "/examples/images/real_face.jpg")) {
                PipelineResult result = pipeline.checkLiveness(image);
                processLivenessResult(result);
            }

            System.out.println("\nChecking liveness for spoof_face.jpg");

            try (Image image = new Image(IDLIVEFACE_HOME + "/examples/images/spoof_face.jpg")) {
                PipelineResult result = pipeline.checkLiveness(image);
                processLivenessResult(result);
            }

            System.out.println("\nChecking liveness for face_not_found.jpg");

            try (Image image = new Image(IDLIVEFACE_HOME + "/examples/images/face_not_found.jpg")) {
                pipeline.checkLiveness(image);
            }

        } catch (FaceException e) {
            System.out.println("Error: " + e.getStatus() + ", message: " + e.getMessage());
        }
    }
}
